@@ -23,20 +23,25 @@ This file is part of DORIS.
 
 import cv2
 
+DEFAULT_CONFIG = {
+"MINIMUM_OBJECT_SIZE": 0, 
+"MAXIMUM_OBJECT_SIZE": 0, 
+"MAXIMUM_OBJECT_EXTENSION": 0,
+"MAXIMUM_DISTANCE_BETWEEN_FRAMES": 0,
+"BLUR_DEFAULT_VALUE": 2,
+"SHOW_CENTROID_DEFAULT": False,
+"SHOW_CONTOUR_DEFAULT": True,
+"THRESHOLD_DEFAULT": 128,
+"ADAPTIVE_BLOCK_SIZE": 10,
+"ADAPTIVE_OFFSET": 10,
+"THRESHOLD_METHOD": 0,
+}
+THRESHOLD_METHODS = ["Simple", "Adaptive (mean)", "Adaptive (Gaussian)"]
+
+
 DEFAULT_FRAME_SCALE = 0.5
 ZOOM_LEVELS = ["2", "1", "0.5", "0.25"]
 
-DIST_MAX = 0
-
-THRESHOLD_METHODS = ["Simple", "Adaptive (mean)", "Adaptive (Gaussian)"]
-
-BLUR_DEFAULT_VALUE = 2
-SHOW_CENTROID_DEFAULT = False
-SHOW_CONTOUR_DEFAULT = True
-
-THRESHOLD_DEFAULT = 128
-ADAPTIVE_BLOCK_SIZE = 10
-ADAPTIVE_OFFSET = 10
 
 
 VIEWER_WIDTH = 480
@@ -92,7 +97,6 @@ RGBSTR_COLORS_LIST = ["FF0000", "00FF00", "0000FF", "FFFF00", "FF00FF", "00FFFF"
         "E00000", "00E000", "0000E0", "E0E000", "E000E0", "00E0E0", "E0E0E0"]
 
 
-
 '''
 COLORS_LIST = ["#FFFF00", "#1CE6FF", "#FF34FF", "#FF4A46", "#008941", "#006FA6", "#A30059",
         "#FFDBE5", "#7A4900", "#0000A6", "#63FFAC", "#B79762", "#004D43", "#8FB0FF", "#997D87",
